@@ -95,9 +95,9 @@ struct _FlatpakTransactionClass
 {
   GObjectClass parent_class;
 
-  void         (*new_operation)        (FlatpakTransaction          *transaction,
-                                        FlatpakTransactionOperation *operation,
-                                        FlatpakTransactionProgress  *progress);
+  void (*new_operation)        (FlatpakTransaction          *transaction,
+                                FlatpakTransactionOperation *operation,
+                                FlatpakTransactionProgress  *progress);
   void (*operation_done)       (FlatpakTransaction          *transaction,
                                 FlatpakTransactionOperation *operation,
                                 const char                  *commit,
@@ -121,7 +121,36 @@ struct _FlatpakTransactionClass
                               const char                    *from_id,
                               const char                    *remote_name,
                               const char                    *url);
-  gpointer padding[10];
+
+  gboolean (*run)            (FlatpakTransaction *transaction,
+                              GCancellable       *cancellable,
+                              GError            **error);
+  gboolean (*end_of_lifed_with_rebase) (FlatpakTransaction *transaction,
+                                        const char         *remote,
+                                        const char         *ref,
+                                        const char         *reason,
+                                        const char         *rebased_to_ref,
+                                        const char        **previous_ids);
+
+  gboolean (*webflow_start) (FlatpakTransaction *transaction,
+                             const char         *remote,
+                             const char         *url,
+                             GVariant           *options,
+                             guint               id);
+  void (*webflow_done) (FlatpakTransaction *transaction,
+                        GVariant           *options,
+                        guint               id);
+
+  gboolean (*basic_auth_start) (FlatpakTransaction *transaction,
+                                const char         *remote,
+                                const char         *realm,
+                                GVariant           *options,
+                                guint               id);
+  void (*install_authenticator)   (FlatpakTransaction *transaction,
+                                   const char         *remote,
+                                   const char         *authenticator_ref);
+
+  gpointer padding[4];
 };
 
 FLATPAK_EXTERN
@@ -131,7 +160,7 @@ FlatpakTransaction *flatpak_transaction_new_for_installation (FlatpakInstallatio
 
 FLATPAK_EXTERN
 void        flatpak_transaction_progress_set_update_frequency (FlatpakTransactionProgress *self,
-                                                               guint                       update_frequency);
+                                                               guint                       update_interval);
 FLATPAK_EXTERN
 char *      flatpak_transaction_progress_get_status (FlatpakTransactionProgress *self);
 FLATPAK_EXTERN
@@ -149,6 +178,10 @@ FlatpakTransactionOperationType flatpak_transaction_operation_get_operation_type
 FLATPAK_EXTERN
 const char *                    flatpak_transaction_operation_get_ref (FlatpakTransactionOperation *self);
 FLATPAK_EXTERN
+GPtrArray *                     flatpak_transaction_operation_get_related_to_ops (FlatpakTransactionOperation *self);
+FLATPAK_EXTERN
+gboolean                        flatpak_transaction_operation_get_is_skipped (FlatpakTransactionOperation *self);
+FLATPAK_EXTERN
 const char *                    flatpak_transaction_operation_get_remote (FlatpakTransactionOperation *self);
 FLATPAK_EXTERN
 GFile *                         flatpak_transaction_operation_get_bundle_path (FlatpakTransactionOperation *self);
@@ -169,9 +202,13 @@ FLATPAK_EXTERN
 void                flatpak_transaction_set_no_pull (FlatpakTransaction *self,
                                                      gboolean            no_pull);
 FLATPAK_EXTERN
+gboolean            flatpak_transaction_get_no_pull (FlatpakTransaction *self);
+FLATPAK_EXTERN
 void                flatpak_transaction_set_no_deploy (FlatpakTransaction *self,
                                                        gboolean            no_deploy);
 FLATPAK_EXTERN
+gboolean            flatpak_transaction_get_no_deploy (FlatpakTransaction *self);
+FLATPAK_EXTERN
 void                flatpak_transaction_set_disable_static_deltas (FlatpakTransaction *self,
                                                                    gboolean            disable_static_deltas);
 FLATPAK_EXTERN
@@ -187,18 +224,29 @@ FLATPAK_EXTERN
 void                flatpak_transaction_set_reinstall (FlatpakTransaction *self,
                                                        gboolean            reinstall);
 FLATPAK_EXTERN
+void                flatpak_transaction_set_no_interaction (FlatpakTransaction *self,
+                                                            gboolean            no_interaction);
+FLATPAK_EXTERN
 void                flatpak_transaction_set_force_uninstall (FlatpakTransaction *self,
                                                              gboolean            force_uninstall);
 FLATPAK_EXTERN
 void                flatpak_transaction_set_default_arch (FlatpakTransaction *self,
                                                           const char         *arch);
 FLATPAK_EXTERN
+void                flatpak_transaction_set_parent_window (FlatpakTransaction *self,
+                                                           const char *parent_window);
+FLATPAK_EXTERN
+const char *        flatpak_transaction_get_parent_window (FlatpakTransaction *self);
+FLATPAK_EXTERN
 void                flatpak_transaction_add_dependency_source (FlatpakTransaction  *self,
                                                                FlatpakInstallation *installation);
 FLATPAK_EXTERN
+void                flatpak_transaction_add_sideload_repo (FlatpakTransaction  *self,
+                                                           const char          *path);
+FLATPAK_EXTERN
 void                flatpak_transaction_add_default_dependency_sources (FlatpakTransaction *self);
 FLATPAK_EXTERN
-gboolean            flatpak_transaction_run (FlatpakTransaction *self,
+gboolean            flatpak_transaction_run (FlatpakTransaction *transaction,
                                              GCancellable       *cancellable,
                                              GError            **error);
 FLATPAK_EXTERN
@@ -208,6 +256,16 @@ FlatpakInstallation *flatpak_transaction_get_installation (FlatpakTransaction *s
 FLATPAK_EXTERN
 GList *flatpak_transaction_get_operations (FlatpakTransaction *self);
 
+FLATPAK_EXTERN
+void               flatpak_transaction_abort_webflow (FlatpakTransaction *self,
+                                                      guint               id);
+FLATPAK_EXTERN
+void               flatpak_transaction_complete_basic_auth (FlatpakTransaction *self,
+                                                            guint id,
+                                                            const char *user,
+                                                            const char *password,
+                                                            GVariant *options);
+
 FLATPAK_EXTERN
 gboolean            flatpak_transaction_add_install (FlatpakTransaction *self,
                                                      const char         *remote,
@@ -215,6 +273,13 @@ gboolean            flatpak_transaction_add_install (FlatpakTransaction *self,
                                                      const char        **subpaths,
                                                      GError            **error);
 FLATPAK_EXTERN
+gboolean            flatpak_transaction_add_rebase (FlatpakTransaction *self,
+                                                    const char         *remote,
+                                                    const char         *ref,
+                                                    const char        **subpaths,
+                                                    const char        **previous_ids,
+                                                    GError            **error);
+FLATPAK_EXTERN
 gboolean            flatpak_transaction_add_install_bundle (FlatpakTransaction *self,
                                                             GFile              *file,
                                                             GBytes             *gpg_data,
